import{I as y}from"./ItemsListing-BxIggw9V.js";import{x as f,r as i,H as m,o as v,I as e,ah as r,b,y as h,z as I,M as p,ak as l}from"./index-Dvn4b3kE.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_3a9a25e3_lang-C3noc3qK.js";import"./ProviderIcon.vue_vue_type_style_index_0_lang-CxRRSRNY.js";import"./VListItem-XlHdRn90.js";import"./VChip-BKGA7XXZ.js";import"./VList-BFxH2oe3.js";import"./VMenu-BxZEtUbH.js";import"./VCard-DDEjK8sh.js";import"./VCardText-CXkKR7ML.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./eventbus-CGRXT3Tn.js";import"./ListItem-CqruFv9t.js";import"./VCheckbox-DXoKCkvo.js";import"./VCheckboxBtn-B2R62I44.js";import"./VSpacer-BpjLI35r.js";/* empty css              */import"./PanelviewItemCompact-CceVDOrI.js";import"./Container-DWavih6c.js";import"./VContainer-C3X0IHcx.js";import"./Toolbar-XsObLWPI.js";import"./VToolbar-Bi9Fkevh.js";import"./VTextField-CNfw_aKz.js";import"./VInfiniteScroll-DgELJAW0.js";import"./layout-BesXh2w9.js";import"./VRow-PHUs5bQJ.js";import"./VVirtualScroll-DezxvIhI.js";import"./VAlert-BKHMgC3s.js";const R=f({name:"Podcasts",__name:"LibraryPodcasts",setup(w){const a=i(!1),s=i(m.libraryPodcastsCount),d=i([]),c=["name","name_desc","sort_name","sort_name_desc","timestamp_added","timestamp_added_desc","timestamp_modified","timestamp_modified_desc","last_played","last_played_desc","play_count","play_count_desc"],u=async function(t){if(t.refresh&&!a.value){for(e.startSync([p.PLAYLIST]),await l(250);e.syncTasks.value.length>0&&e.syncTasks.value.filter(o=>o.media_types.includes(p.PLAYLIST)).length!=0;)await l(500);await l(500)}return a.value=!1,_(t),await e.getLibraryPodcasts(t.favoritesOnly||void 0,t.search,t.limit,t.offset,t.sortBy)},_=async function(t){if(!t.favoritesOnly){s.value=m.libraryPodcastsCount;return}s.value=await e.getLibraryPodcastsCount(t.favoritesOnly||!1)};return v(()=>{const t=e.subscribe_multi([r.MEDIA_ITEM_ADDED,r.MEDIA_ITEM_UPDATED,r.MEDIA_ITEM_DELETED],o=>{var n;(n=o.object_id)!=null&&n.startsWith("library://podcast")&&(a.value=!0)});b(t)}),(t,o)=>(h(),I(y,{itemtype:"podcasts",path:"librarypodcasts","show-duration":!1,"show-provider":!0,"show-favorites-only-filter":!0,"load-paged-data":u,"show-library":!0,"sort-keys":c,"update-available":a.value,title:t.$t("podcasts"),"allow-key-hooks":!0,"show-search-button":!0,"extra-menu-items":d.value,icon:"mdi-podcast","restore-state":!0,total:s.value},null,8,["update-available","title","extra-menu-items","total"]))}});export{R as default};
