import{I as _}from"./ItemsListing-BxIggw9V.js";import{x as v,r as l,H as p,o as b,I as a,ah as n,b as k,y as T,D as h,n as c,G as E,F as w,M as m,ak as u}from"./index-Dvn4b3kE.js";import{_ as D}from"./AddManualLink.vue_vue_type_script_setup_true_lang-BujK_7Tz.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_3a9a25e3_lang-C3noc3qK.js";import"./ProviderIcon.vue_vue_type_style_index_0_lang-CxRRSRNY.js";import"./VListItem-XlHdRn90.js";import"./VChip-BKGA7XXZ.js";import"./VList-BFxH2oe3.js";import"./VMenu-BxZEtUbH.js";import"./VCard-DDEjK8sh.js";import"./VCardText-CXkKR7ML.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./eventbus-CGRXT3Tn.js";import"./ListItem-CqruFv9t.js";import"./VCheckbox-DXoKCkvo.js";import"./VCheckboxBtn-B2R62I44.js";import"./VSpacer-BpjLI35r.js";/* empty css              */import"./PanelviewItemCompact-CceVDOrI.js";import"./Container-DWavih6c.js";import"./VContainer-C3X0IHcx.js";import"./Toolbar-XsObLWPI.js";import"./VToolbar-Bi9Fkevh.js";import"./VTextField-CNfw_aKz.js";import"./VInfiniteScroll-DgELJAW0.js";import"./layout-BesXh2w9.js";import"./VRow-PHUs5bQJ.js";import"./VVirtualScroll-DezxvIhI.js";import"./VAlert-BKHMgC3s.js";import"./VDialog-CHkPjb9d.js";const at=v({name:"Tracks",__name:"LibraryTracks",setup(A){const o=l(!1),s=l(p.libraryTracksCount),i=l(!1),d=["name","name_desc","sort_name","sort_name_desc","duration","duration_desc","timestamp_added","timestamp_added_desc","last_played","last_played_desc","play_count","play_count_desc"];b(()=>{const t=a.subscribe_multi([n.MEDIA_ITEM_ADDED,n.MEDIA_ITEM_UPDATED,n.MEDIA_ITEM_DELETED],e=>{var r;(r=e.object_id)!=null&&r.startsWith("library://track")&&(o.value=!0)});k(t)});const y=async function(t){if(t.favoritesOnly=t.favoritesOnly||void 0,t.refresh&&!o.value){for(a.startSync([m.TRACK]),await u(250);a.syncTasks.value.length>0&&a.syncTasks.value.filter(e=>e.media_types.includes(m.TRACK)).length!=0;)await u(500);await u(500)}return o.value=!1,f(t),await a.getLibraryTracks(t.favoritesOnly,t.search,t.limit,t.offset,t.sortBy)},f=async function(t){if(!t.favoritesOnly){s.value=p.libraryTracksCount;return}s.value=await a.getLibraryTracksCount(t.favoritesOnly||!1)};return(t,e)=>(T(),h(w,null,[c(_,{itemtype:"tracks",path:"librarytracks","show-provider":!1,"show-favorites-only-filter":!0,"show-track-number":!1,"load-paged-data":y,"sort-keys":d,"show-album":!0,"update-available":o.value,title:t.$t("tracks"),"show-search-button":!0,"allow-key-hooks":!0,"extra-menu-items":[{label:"add_url_item",labelArgs:[],action:()=>{i.value=!0},icon:"mdi-playlist-plus"}],icon:"mdi-music-note","restore-state":!0,total:s.value},null,8,["update-available","title","extra-menu-items","total"]),c(D,{modelValue:i.value,"onUpdate:modelValue":e[0]||(e[0]=r=>i.value=r),type:E(m).RADIO},null,8,["modelValue","type"])],64))}});export{at as default};
