import{m as A,a as F,u as I,V as t,b as l}from"./VCheckboxBtn-B2R62I44.js";import{p as B,a6 as U,g as M,k as R,aM as q,c as D,b1 as N,n as u,q as r}from"./index-Dvn4b3kE.js";import{i as $}from"./VListItem-XlHdRn90.js";const j=B({...A(),...U(F(),["inline"])},"VCheckbox"),G=M()({name:"VCheckbox",inheritAttrs:!1,props:j(),emits:{"update:modelValue":e=>!0,"update:focused":e=>!0},setup(e,c){let{attrs:d,slots:a}=c;const s=R(e,"modelValue"),{isFocused:n,focus:i,blur:m}=I(e),V=q(),b=D(()=>e.id||`checkbox-${V}`);return $(()=>{const[p,f]=N(d),k=t.filterProps(e),v=l.filterProps(e);return u(t,r({class:["v-checkbox",e.class]},p,k,{modelValue:s.value,"onUpdate:modelValue":o=>s.value=o,id:b.value,focused:n.value,style:e.style}),{...a,default:o=>{let{id:x,messagesId:h,isDisabled:P,isReadonly:C,isValid:y}=o;return u(l,r(v,{id:x.value,"aria-describedby":h.value,disabled:P.value,readonly:C.value},f,{error:y.value===!1,modelValue:s.value,"onUpdate:modelValue":g=>s.value=g,onFocus:i,onBlur:m}),a)}})}),{}}});export{G as V};
