import{x as s,af as m,c as n,R as e,y as l,D as c,n as u,I as f}from"./index-Dvn4b3kE.js";import{I as h}from"./ItemsListing-BxIggw9V.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_3a9a25e3_lang-C3noc3qK.js";import"./ProviderIcon.vue_vue_type_style_index_0_lang-CxRRSRNY.js";import"./VListItem-XlHdRn90.js";import"./VChip-BKGA7XXZ.js";import"./VList-BFxH2oe3.js";import"./VMenu-BxZEtUbH.js";import"./VCard-DDEjK8sh.js";import"./VCardText-CXkKR7ML.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./eventbus-CGRXT3Tn.js";import"./ListItem-CqruFv9t.js";import"./VCheckbox-DXoKCkvo.js";import"./VCheckboxBtn-B2R62I44.js";import"./VSpacer-BpjLI35r.js";/* empty css              */import"./PanelviewItemCompact-CceVDOrI.js";import"./Container-DWavih6c.js";import"./VContainer-C3X0IHcx.js";import"./Toolbar-XsObLWPI.js";import"./VToolbar-Bi9Fkevh.js";import"./VTextField-CNfw_aKz.js";import"./VInfiniteScroll-DgELJAW0.js";import"./layout-BesXh2w9.js";import"./VRow-PHUs5bQJ.js";import"./VVirtualScroll-DezxvIhI.js";import"./VAlert-BKHMgC3s.js";const P=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),p=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),a=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":a,"sort-keys":["original","name","name_desc"],title:p.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{P as default};
