import{I as y}from"./ItemsListing-BxIggw9V.js";import{x as b,r as s,H as u,o as f,I as o,ah as r,b as k,y as v,z as h,M as m,ak as l}from"./index-Dvn4b3kE.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_3a9a25e3_lang-C3noc3qK.js";import"./ProviderIcon.vue_vue_type_style_index_0_lang-CxRRSRNY.js";import"./VListItem-XlHdRn90.js";import"./VChip-BKGA7XXZ.js";import"./VList-BFxH2oe3.js";import"./VMenu-BxZEtUbH.js";import"./VCard-DDEjK8sh.js";import"./VCardText-CXkKR7ML.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./eventbus-CGRXT3Tn.js";import"./ListItem-CqruFv9t.js";import"./VCheckbox-DXoKCkvo.js";import"./VCheckboxBtn-B2R62I44.js";import"./VSpacer-BpjLI35r.js";/* empty css              */import"./PanelviewItemCompact-CceVDOrI.js";import"./Container-DWavih6c.js";import"./VContainer-C3X0IHcx.js";import"./Toolbar-XsObLWPI.js";import"./VToolbar-Bi9Fkevh.js";import"./VTextField-CNfw_aKz.js";import"./VInfiniteScroll-DgELJAW0.js";import"./layout-BesXh2w9.js";import"./VRow-PHUs5bQJ.js";import"./VVirtualScroll-DezxvIhI.js";import"./VAlert-BKHMgC3s.js";const R=b({name:"Audiobooks",__name:"LibraryAudiobooks",setup(A){const e=s(!1),i=s(u.libraryAudiobooksCount),p=s([]),d=["name","name_desc","sort_name","sort_name_desc","timestamp_added","timestamp_added_desc","timestamp_modified","timestamp_modified_desc","last_played","last_played_desc","play_count","play_count_desc"],c=async function(t){if(t.refresh&&!e.value){for(o.startSync([m.PLAYLIST]),await l(250);o.syncTasks.value.length>0&&o.syncTasks.value.filter(a=>a.media_types.includes(m.PLAYLIST)).length!=0;)await l(500);await l(500)}return e.value=!1,_(t),await o.getLibraryAudiobooks(t.favoritesOnly||void 0,t.search,t.limit,t.offset,t.sortBy)},_=async function(t){if(!t.favoritesOnly){i.value=u.libraryAudiobooksCount;return}i.value=await o.getLibraryAudiobooksCount(t.favoritesOnly||!1)};return f(()=>{const t=o.subscribe_multi([r.MEDIA_ITEM_ADDED,r.MEDIA_ITEM_UPDATED,r.MEDIA_ITEM_DELETED],a=>{var n;(n=a.object_id)!=null&&n.startsWith("library://audiobook")&&(e.value=!0)});k(t)}),(t,a)=>(v(),h(y,{itemtype:"audiobooks",path:"libraryaudiobooks","show-duration":!1,"show-provider":!0,"show-favorites-only-filter":!0,"load-paged-data":c,"show-library":!0,"sort-keys":d,"update-available":e.value,title:t.$t("audiobooks"),"allow-key-hooks":!0,"show-search-button":!0,"extra-menu-items":p.value,icon:"mdi-book-play-outline","restore-state":!0,total:i.value},null,8,["update-available","title","extra-menu-items","total"]))}});export{R as default};
